@@ -433,7 +433,7 @@ sub sample_evenly {
 sub is_valid_extremum {
 	my ($class, $extremum) = @_;
 	no warnings 'numeric';
-	if ($extremum < 0) {
+	if ($extremum <= 0) {
 		# no negative values:
 		$@ = 'must be positive for logarithmic scaling';
 		return 0;
@@ -506,15 +506,19 @@ plots
 
 =head1 LICENSE AND COPYRIGHT
 
-Portions of this module's code are copyright (c) 2011 The Board of Trustees at
-the University of Illinois.
+Unless otherwise stated, all contributions in code and documentation are
+copyright (c) their respective authors, all rights reserved.
+
+Portions of this module's code are copyright (c) 2011 The Board of
+Trustees at the University of Illinois.
 
 Portions of this module's code are copyright (c) 2011-2013 Northwestern
 University.
 
-This module's documentation are copyright (c) 2011-2013 David Mertens.
+Portions of this module's code are copyright (c) 2013-2014 Dickinson
+College.
 
-All rights reserved.
+This module's documentation is copyright (c) 2011-2014 David Mertens.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
